@@ -1,4 +1,8 @@
+import typing as t
+
+from djask.db.models import Model
 from .types import ModelList, ModelType
+from .exceptions import ModelTypeError
 
 
 class ModelFunctionalityMixin:
@@ -6,7 +10,8 @@ class ModelFunctionalityMixin:
     A mixin that adds some SQL functionalities to the classes which inherit it.
     Those classes which inherit it are expected to be subclasses of :class:`~flask.Blueprint` or :class:`~flask.Flask`.
 
-    .. versionadded: 0.1.0
+    .. versionadded:: 0.4.1
+    .. versionadded:: 0.1.0
     """
 
     models: ModelList = []
@@ -27,9 +32,11 @@ class ModelFunctionalityMixin:
         :param model: The model to register
         :return: None
         """
+        if not isinstance(model, type(Model)):
+            raise ModelTypeError
         self.models.append(model)
 
-    def register_models(self, models: ModelType) -> None:
+    def register_models(self, models: t.Iterable[ModelType]) -> None:
         """
         Register multiple models at a time.
         :param models: The models to register
